@@ -32,7 +32,7 @@
   #define XDMF_BYTE_ORDER_LITTLE
 #endif
 
-#define XDMF_SYSTEM Linux-6.12.16-1-lts
+#define XDMF_SYSTEM Linux-6.17.7-arch1-1
 
 #define XDMF_VOID_VALID
 #ifndef XDMF_VOID_VALID
